@@ -9,7 +9,7 @@
 #' @return The object returned depends on the \dots{} argument which is passed on to the \code{coef}
 #' method for \code{PTReg} objects.
 #' \item{intercept}{The intercept estimate.}
-#' \item{alpha}{Matrix of the coefficients for main environmental effects.}
+#' \item{alpha}{The matrix of the coefficients for main environmental effects.}
 #' \item{beta}{The matrix of the regression coefficients for all main genetic effects (the first row) and interactions.}
 #' @seealso \code{PTReg}, and \code{predict} methods, and
 #' \code{bic.PTReg}.
@@ -20,10 +20,8 @@
 #' @export coef.PTReg
 coef.PTReg<-function(object,...){
   beta_estimate=object$beta
-  p=dim(beta_estimate)[2]
-  q=dim(beta_estimate)[1]-1
   alpha_estimate=object$alpha
   intercept_estimate=object$intercept
   #b_estimate=matrix(beta_estimate,p*(q+1),1)
   return(list(intercept=intercept_estimate,alpha=alpha_estimate,beta=beta_estimate))
-  }
+}
